@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.Backup 1.17.71\n"
-        "Version:         1.17.71.post1\n"
-        "Builder version: 4.12.0\n"
+        "Type annotations for boto3.Backup 1.17.74\n"
+        "Version:         1.17.74\n"
+        "Builder version: 4.13.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-backup/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/backup.html#Backup\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/backup.html#Backup\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.71.post1")
+    print("1.17.74")
 
 
 def main() -> None:
